@@ -16,7 +16,11 @@ sub new {
 			substr($sub_name, 6) || '');
  		return($sub_body);
         };
-	bless($generator, $class);
+	my $self = [$generator];
+	bless($self, $class);
+	Internals::SvREADONLY(@{$self}, 1);
+
+	return($self);
 }
 
 1;
\ No newline at end of file
