@@ -19,7 +19,11 @@ sub new {
 
  		return($sub_text);
         };
-	bless($generator, $class);
+	my $self = [$generator];
+	bless($self, $class);
+	Internals::SvREADONLY(@{$self}, 1);
+
+	return($self);
 }
 
 1;
\ No newline at end of file
